@@ -1,9 +1,13 @@
+from __future__ import unicode_literals
+
 from django import template
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
+
 from .compat import parse_bits
 from ..cachefiles import ImageCacheFile
 from ..registry import generator_registry
+from ..lib import force_text
 
 
 register = template.Library()
@@ -40,7 +44,7 @@ class GenerateImageAssignmentNode(template.Node):
         self._variable_name = variable_name
 
     def get_variable_name(self, context):
-        return unicode(self._variable_name)
+        return force_text(self._variable_name)
 
     def render(self, context):
         variable_name = self.get_variable_name(context)
@@ -70,7 +74,7 @@ class GenerateImageTagNode(template.Node):
         attrs['src'] = file.url
         attr_str = ' '.join('%s="%s"' % (escape(k), escape(v)) for k, v in
                 attrs.items())
-        return mark_safe(u'<img %s />' % attr_str)
+        return mark_safe('<img %s />' % attr_str)
 
 
 class ThumbnailAssignmentNode(template.Node):
@@ -83,7 +87,7 @@ class ThumbnailAssignmentNode(template.Node):
         self._generator_kwargs = generator_kwargs
 
     def get_variable_name(self, context):
-        return unicode(self._variable_name)
+        return force_text(self._variable_name)
 
     def render(self, context):
         variable_name = self.get_variable_name(context)
@@ -131,7 +135,7 @@ class ThumbnailImageTagNode(template.Node):
         attrs['src'] = file.url
         attr_str = ' '.join('%s="%s"' % (escape(k), escape(v)) for k, v in
                 attrs.items())
-        return mark_safe(u'<img %s />' % attr_str)
+        return mark_safe('<img %s />' % attr_str)
 
 
 def parse_ik_tag_bits(parser, bits):
